automake-ng
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Automake-NG] [PATCH 01/33] [ng] rename: am__dist_* -> am.dist.*


From: Stefano Lattarini
Subject: [Automake-NG] [PATCH 01/33] [ng] rename: am__dist_* -> am.dist.*
Date: Sat, 21 Jul 2012 14:55:33 +0200

Here is the complete list of renames:

    am__dist_common        ->   am.dist.common-files
    am__dist_sources       ->   am.dist.sources
    am__dist_files         ->   am.dist.all-files
    am__dist_files_1       ->   am.dist.files-tmp1
    am__dist_files_2       ->   am.dist.files-tmp2
    am__dist_files_cooked  ->   am.dist.files-cooked
    am__dist_parent_dirs   ->   am.dist.parent-dirs

Signed-off-by: Stefano Lattarini <address@hidden>
---
 NG-NEWS                           |    6 ++---
 automake.in                       |   12 +++++-----
 lib/am/configure.am               |    4 ++--
 lib/am/data.am                    |    2 +-
 lib/am/distdir.am                 |   44 ++++++++++++++++++-------------------
 lib/am/java.am                    |    2 +-
 lib/am/lisp.am                    |    2 +-
 lib/am/python.am                  |    2 +-
 lib/am/scripts.am                 |    2 +-
 lib/am/texi-vers.am               |    2 +-
 syntax-checks.mk                  |    9 +++-----
 t/autodist-aclocal-m4.sh          |    2 +-
 t/autodist-configure-no-subdir.sh |    2 +-
 t/autodist-stamp-vti.sh           |    2 +-
 t/autodist-subdir.sh              |   10 ++++-----
 t/autodist.sh                     |    6 ++---
 t/colon5.sh                       |    2 +-
 t/colon7.sh                       |    6 ++---
 t/confh.sh                        |    4 ++--
 t/confh8.sh                       |    8 +++----
 t/depdist.sh                      |    2 +-
 t/dist-auxfile.sh                 |    8 +++----
 t/distcom-subdir.sh               |    4 ++--
 t/distcom2.sh                     |    6 ++---
 t/distcom3.sh                     |    4 ++--
 t/distcom4.sh                     |    2 +-
 t/distcom5.sh                     |    4 ++--
 t/hdr-vars-defined-once.sh        |    4 ++--
 t/insh2.sh                        |    2 +-
 t/libobj7.sh                      |    8 +++----
 t/nodist.sh                       |    4 ++--
 t/nodist3.sh                      |    2 +-
 t/pr2.sh                          |    2 +-
 t/substref.sh                     |    4 ++--
 t/test-driver-is-distributed.sh   |    2 +-
 t/txinfo.sh                       |    4 ++--
 t/txinfo2.sh                      |    4 ++--
 t/txinfo8.sh                      |    4 ++--
 t/vtexi3.sh                       |    4 ++--
 t/vtexi4.sh                       |    4 ++--
 t/yacc-basic.sh                   |    2 +-
 t/yacc-cxx.sh                     |    2 +-
 t/yacc-d-basic.sh                 |    2 +-
 t/yacc-d-cxx.sh                   |    2 +-
 t/yacc-lex-cxx-alone.sh           |    4 ++--
 45 files changed, 108 insertions(+), 111 deletions(-)

diff --git a/NG-NEWS b/NG-NEWS
index 22e2dfc..ca91927 100644
--- a/NG-NEWS
+++ b/NG-NEWS
@@ -217,9 +217,9 @@ Distribution
   to be internal variables.  But that was not clear from their names.
   So we have renamed rename like this:
 
-    DISTFILES     =>  am__dist_files
-    DIST_COMMON   =>  am__dist_common
-    DIST_SOURCES  =>  am__dist_sources
+    DISTFILES     =>  am.dist.all-files
+    DIST_COMMON   =>  am.dist.common-files
+    DIST_SOURCES  =>  am.dist.sources
 
   Do not use any of these variables in your Makefiles!
 
diff --git a/automake.in b/automake.in
index 6e7da4b..4b2faf9 100644
--- a/automake.in
+++ b/automake.in
@@ -3375,10 +3375,10 @@ sub handle_dist ()
   # check that.  But if the file is in a subdir without a Makefile,
   # we want to distribute it here if we are doing '.'.  Ugly!
   # Also, in some corner cases, it's possible that the following code
-  # will cause the same file to appear in the $(am__dist_common) variables
-  # of two distinct Makefiles; but this is not a problem, since the
-  # 'distdir' target in 'lib/am/distdir.am' can deal with the same
-  # file being distributed multiple times.
+  # will cause the same file to appear in the $(am.dist.common-files)
+  # variables of two distinct Makefiles; but this is not a problem,
+  # since the 'distdir' target in 'lib/am/distdir.am' can deal with
+  # the same file being distributed multiple times.
   # See also automake bug#9651.
   if ($relative_dir eq '.')
     {
@@ -6830,7 +6830,7 @@ sub require_conf_file_with_macro ($$$@)
 
 ################################################################
 
-# Push a list of files onto dist_common.
+# Push a list of files onto @dist_common.
 sub push_dist_common
 {
   prog_error "push_dist_common run after handle_dist"
@@ -6930,7 +6930,7 @@ sub generate_makefile ($$)
 
   # Variables used by distdir.am and tags.am.
   define_variable ('SOURCES', INTERNAL, @sources);
-  define_variable ('am__dist_sources', INTERNAL, @dist_sources)
+  define_variable ('am.dist.sources', INTERNAL, @dist_sources)
     unless option 'no-dist';
 
   handle_texinfo;
diff --git a/lib/am/configure.am b/lib/am/configure.am
index 9c55e6e..34b2d32 100644
--- a/lib/am/configure.am
+++ b/lib/am/configure.am
@@ -71,7 +71,7 @@
 ## Avoid the "deleted header file" problem for the dependencies.
 ?HAVE-MAKEFILE-IN-DEPS?%MAKEFILE-IN-DEPS%:
 
-am__dist_common += %MAKEFILE-AM%
+am.dist.common-files += %MAKEFILE-AM%
 
 
 ## --------------------------- ##
@@ -83,7 +83,7 @@ if %?TOPDIR_P%
 ## don't exist.  This is especially important for configure, since it
 ## won't be created until autoconf is run -- which might be after
 ## automake is run.
-am__dist_common += $(top_srcdir)/configure $(am__configure_deps)
+am.dist.common-files += $(top_srcdir)/configure $(am__configure_deps)
 endif %?TOPDIR_P%
 
 $(top_builddir)/config.status: $(top_srcdir)/configure 
$(CONFIG_STATUS_DEPENDENCIES)
diff --git a/lib/am/data.am b/lib/am/data.am
index 7417266..379bc15 100644
--- a/lib/am/data.am
+++ b/lib/am/data.am
@@ -96,5 +96,5 @@ endif %?INSTALL%
 ## -------------- ##
 
 if %?DIST%
-am__dist_common += %DISTVAR%
+am.dist.common-files += %DISTVAR%
 endif %?DIST%
diff --git a/lib/am/distdir.am b/lib/am/distdir.am
index fd2c39d..bf74c5d 100644
--- a/lib/am/distdir.am
+++ b/lib/am/distdir.am
@@ -14,24 +14,24 @@
 ## You should have received a copy of the GNU General Public License
 ## along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-am__dist_common += %DIST-COMMON%
+am.dist.common-files += %DIST-COMMON%
 
 ## Use 'sort', not 'am__uniq', for performance reasons.  Luckily, we
 ## don't care in which order the distributed files are.
-am__dist_files = $(call am__memoize,am__dist_files,$(strip $(sort \
-  $(am__dist_common) $(am__dist_sources) $(TEXINFOS) $(EXTRA_DIST))))
+am.dist.all-files = $(call am__memoize,am.dist.all-files,$(strip $(sort \
+  $(am.dist.common-files) $(am.dist.sources) $(TEXINFOS) $(EXTRA_DIST))))
 
-## Try to avoid repeated slashed in the entries, to make the
-## filtering in the 'am__dist_files_1' definition below more reliable.
-## This idiom should compress up to four consecutive '/' characters in
-## each $(am__dist_files) entry.
-am__dist_files_1 = $(call am__memoize,am__dist_files_1, \
-  $(subst //,/,$(subst //,/,$(am__dist_files))))
+## Try to avoid repeated slashes in the entries, to make the filtering
+## in the 'am.dist.files-tmp2' definition below more reliable.
+## This idiom should compress up to four consecutive '/' characters
+## in each $(am.dist.all-files) entry.
+am.dist.files-tmp1 = $(call am__memoize,am.dist.files-tmp1, \
+  $(subst //,/,$(subst //,/,$(am.dist.all-files))))
 
-am__dist_files_2 = $(call am__memoize,am__dist_files_2, \
+am.dist.files-tmp2 = $(call am__memoize,am.dist.files-tmp2, \
 ## Files filtered out here require an ad-hoc "munging"; see the two
 ## following 'patsubst's.
-  $(filter-out $(srcdir)/% $(top_srcdir)/%, $(am__dist_files_1)) \
+  $(filter-out $(srcdir)/% $(top_srcdir)/%, $(am.dist.files-tmp1)) \
 ## Let's strip leading $(srcdir) (which might appears in EXTRA_DIST,
 ## especially if one want to use the $(wildcard) built-in in there),
 ## so that in our 'distdir' recipe below we can loop on the list of
@@ -44,18 +44,18 @@ am__dist_files_2 = $(call am__memoize,am__dist_files_2, \
 ## present in mainstream Automake, and concerns only such corner-case
 ## situations that it's probably not worth worrying about.
   $(patsubst $(srcdir)/%, %, \
-             $(filter $(srcdir)/%, $(am__dist_files_1))) \
+             $(filter $(srcdir)/%, $(am.dist.files-tmp1))) \
 ## Also rewrite $(top_srcdir) -- which can sometimes appear in
-## $(am__dist_common), and can be absolute -- by $(top_builddir)
+## $(am.dist.common-files), and can be absolute -- by $(top_builddir)
 ## (which is always relative).  If needed, $(srcdir) will be
 ## prepended later by our VPATH-aware rules.
 ## The same caveats reported above apply.
   $(patsubst $(top_srcdir)/%, $(top_builddir)/%, \
-             $(filter $(top_srcdir)/%, $(am__dist_files_1))))
+             $(filter $(top_srcdir)/%, $(am.dist.files-tmp1))))
 
 ## Strip extra whitespaces, for more safety.
-am__dist_files_cooked = \
-  $(call am__memoize,am__dist_files_cooked,$(strip $(am__dist_files_2)))
+am.dist.files-cooked = \
+  $(call am__memoize,am.dist.files-cooked,$(strip $(am.dist.files-tmp2)))
 
 ## Given the pre-processing done above to the list of distributed files,
 ## this definition ensures that we won't try to create the wrong
@@ -65,9 +65,9 @@ am__dist_files_cooked = \
 ## will allow our rules to correctly create "$(distdir)/subdir", and not
 ## "$(distdir)/$(srcdir)/subdir" -- which, in a VPATH build where
 ## "$(subdir) = ..", would be the build directory!
-am__dist_parent_dirs = \
-  $(call am__memoize,am__dist_parent_dirs,$(strip $(sort \
-    $(filter-out ., $(patsubst ./%,%,$(dir $(am__dist_files_cooked)))))))
+am.dist.parent-dirs = \
+  $(call am__memoize,am.dist.parent-dirs,$(strip $(sort \
+    $(filter-out ., $(patsubst ./%,%,$(dir $(am.dist.files-cooked)))))))
 
 am.mkdir-for-dist = \
   @$(MKDIR_P) $(patsubst %,"$(distdir)"/%,$1)$(am__newline)
@@ -133,7 +133,7 @@ if %?SUBDIRS%
 AM_RECURSIVE_TARGETS += distdir
 endif %?SUBDIRS%
 
-distdir: $(am__dist_files) | $(am__dir)
+distdir: $(am.dist.all-files) | $(am__dir)
 ##
 ## For Gnits users, this is pretty handy.  Look at 15 lines
 ## in case some explanatory text is desirable.
@@ -157,7 +157,7 @@ if %?TOPDIR_P%
 endif %?TOPDIR_P%
 ## Make the subdirectories for the files, avoiding to exceed command
 ## line length limitations.
-       $(call am.xargs-map,am.mkdir-for-dist,$(am__dist_parent_dirs))
+       $(call am.xargs-map,am.mkdir-for-dist,$(am.dist.parent-dirs))
 ## Install the files and directories, applying a "VPATH rewrite"
 ## by hand where needed.
 ## To get the files in the distribution directory, use 'cp', not 'ln'.
@@ -166,7 +166,7 @@ endif %?TOPDIR_P%
 ## easily happen if "gettextize" was run on the distribution.
        @rm -f $(am__dir)/address@hidden
        $(call am.xargs-map,am.write-list-of-distfiles, \
-              $(am__dist_files_cooked))
+              $(am.dist.files-cooked))
        @while read file; do \
 ## Always look for the file or directory to distribute in the build
 ## directory first, in VPATH spirit.
diff --git a/lib/am/java.am b/lib/am/java.am
index 7b52bdc..7849344 100644
--- a/lib/am/java.am
+++ b/lib/am/java.am
@@ -90,5 +90,5 @@ am__clean_files += class%NDIR%.stamp
 ## -------------- ##
 
 if %?DIST%
-am__dist_common += %DISTVAR%
+am.dist.common-files += %DISTVAR%
 endif %?DIST%
diff --git a/lib/am/lisp.am b/lib/am/lisp.am
index 7b61e34..40ac35e 100644
--- a/lib/am/lisp.am
+++ b/lib/am/lisp.am
@@ -149,5 +149,5 @@ am__clean_files += elc-stamp $(ELCFILES)
 ## -------------- ##
 
 if %?DIST%
-am__dist_common += %DISTVAR%
+am.dist.common-files += %DISTVAR%
 endif %?DIST%
diff --git a/lib/am/python.am b/lib/am/python.am
index c2226cd..1ec6fbc 100644
--- a/lib/am/python.am
+++ b/lib/am/python.am
@@ -126,5 +126,5 @@ endif %?INSTALL%
 ## -------------- ##
 
 if %?DIST%
-am__dist_common += %DISTVAR%
+am.dist.common-files += %DISTVAR%
 endif %?DIST%
diff --git a/lib/am/scripts.am b/lib/am/scripts.am
index 6ae3362..f15edcb 100644
--- a/lib/am/scripts.am
+++ b/lib/am/scripts.am
@@ -95,7 +95,7 @@ endif %?INSTALL%
 ## -------------- ##
 
 if %?DIST%
-am__dist_common += %DISTVAR%
+am.dist.common-files += %DISTVAR%
 endif %?DIST%
 
 
diff --git a/lib/am/texi-vers.am b/lib/am/texi-vers.am
index 4c13130..0608e0b 100644
--- a/lib/am/texi-vers.am
+++ b/lib/am/texi-vers.am
@@ -14,7 +14,7 @@
 ## You should have received a copy of the GNU General Public License
 ## along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-am__dist_common += %VTEXI% %STAMPVTI%
+am.dist.common-files += %VTEXI% %STAMPVTI%
 
 ## Don't give this rule a command (even '@:').
 ## %STAMPVTI% is always newer than %VTEXI%, so this rule is always
diff --git a/syntax-checks.mk b/syntax-checks.mk
index 7bd071f..b1e1203 100644
--- a/syntax-checks.mk
+++ b/syntax-checks.mk
@@ -321,9 +321,9 @@ sc_no_am_makeflags:
        fi
 
 # Modern names for internal variables that had a bad name once.
-modern.DISTFILES = am__dist_files
-modern.DIST_COMMON = am__dist_common
-modern.DIST_SOURCES = am__dist_sources
+modern.DISTFILES = am.dist.all-files
+modern.DIST_COMMON = am.dist.common-files
+modern.DIST_SOURCES = am.dist.sources
 modern.am__TEST_BASES = am__test_bases
 modern.am__TEST_LOGS = am__test_logs
 modern.am__TEST_RESULTS = am__test_results
@@ -348,9 +348,6 @@ $(sc_renamed_variables_rules): sc_no_% :
        fi
 
 # Variables whose name is prone to typos.
-fixtypo.am__distfiles = am__dist_files
-fixtypo.am__distcommon = am__dist_common
-fixtypo.am__distsources = am__dist_sources
 
 define typos-for-clean
 
diff --git a/t/autodist-aclocal-m4.sh b/t/autodist-aclocal-m4.sh
index f879dea..1c86490 100755
--- a/t/autodist-aclocal-m4.sh
+++ b/t/autodist-aclocal-m4.sh
@@ -34,7 +34,7 @@ cat > Makefile.am <<'END'
 test: distdir
        ls -l $(distdir)
        test ! -f $(distdir)/aclocal.m4
-       echo $(am__dist_files) $(am__dist_common) \
+       echo $(am.dist.all-files) $(am.dist.common-files) \
           | grep 'aclocal\.m4' && exit 1; :
 check-local: test
 END
diff --git a/t/autodist-configure-no-subdir.sh 
b/t/autodist-configure-no-subdir.sh
index 458142c..dbb62c9 100755
--- a/t/autodist-configure-no-subdir.sh
+++ b/t/autodist-configure-no-subdir.sh
@@ -47,7 +47,7 @@ configure:
 configure.ac:
        $(dontbuild)
 check-local:
-       echo $(am__dist_files) $(am__dist_common) \
+       echo $(am.dist.all-files) $(am.dist.common-files) \
           | grep 'configure' && exit 1; :
 END
 
diff --git a/t/autodist-stamp-vti.sh b/t/autodist-stamp-vti.sh
index 5944f30..9731010 100755
--- a/t/autodist-stamp-vti.sh
+++ b/t/autodist-stamp-vti.sh
@@ -30,7 +30,7 @@ info_TEXINFOS = foo.texi
 .PHONY: test
 test: all distdir
        ls -l $(distdir)
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]stamp-vti '
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]stamp-vti '
        test -f $(distdir)/stamp-vti
 END
 
diff --git a/t/autodist-subdir.sh b/t/autodist-subdir.sh
index 657dcc2..2b76c5d 100755
--- a/t/autodist-subdir.sh
+++ b/t/autodist-subdir.sh
@@ -48,8 +48,8 @@ cat > Makefile.am <<'END'
 SUBDIRS = sub
 check-local:
 ## For debugging.
-       @echo am__dist_common:
-       @for f in $(am__dist_common); do echo "  $$f"; done
+       @echo am.dist.common-files:
+       @for f in $(am.dist.common-files); do echo "  $$f"; done
        @echo DISTDIR:
        @ls -l $(distdir) | sed 's/^/  /'
 ## Now the checks.
@@ -66,8 +66,8 @@ cat > sub/Makefile.am <<'END'
 include distfiles.am
 check-local:
 ## For debugging.
-       @echo am__dist_common:
-       @for f in $(am__dist_common); do echo "  $$f"; done
+       @echo am.dist.common-files:
+       @for f in $(am.dist.common-files); do echo "  $$f"; done
        @echo DISTDIR:
        @ls -l $(distdir) | sed 's/^/  /'
 ## Now the checks.
@@ -76,7 +76,7 @@ check-local:
 ## Some filenames might contain dots, but this won't cause spurious
 ## failures, and "spurious successes" are so unlikely that they're
 ## not worth worrying about.
-         echo ' ' $(am__dist_common) ' ' | grep "[ /]$$f " >/dev/null \
+         echo ' ' $(am.dist.common-files) ' ' | grep "[ /]$$f " >/dev/null \
            || { echo $$f: distcom fail >&2; exit 1; }; \
        done
 END
diff --git a/t/autodist.sh b/t/autodist.sh
index 2ec7418..0f6c2de 100755
--- a/t/autodist.sh
+++ b/t/autodist.sh
@@ -47,8 +47,8 @@ cat > Makefile.am <<'END'
 include distfiles.am
 check-local:
 ## For debugging.
-       @echo am__dist_common:
-       @for f in $(am__dist_common); do echo "  $$f"; done
+       @echo am.dist.common-files:
+       @for f in $(am.dist.common-files); do echo "  $$f"; done
        @echo DISTDIR:
        @ls -l $(distdir) | sed 's/^/  /'
 ## Now the checks.
@@ -59,7 +59,7 @@ check-local:
 ## Some filenames might contain dots, but this won't cause spurious
 ## failures, and "spurious successes" are so unlikely that they're
 ## not worth worrying about.
-         echo ' ' $(am__dist_common) ' ' | grep "[ /]$$f " >/dev/null \
+         echo ' ' $(am.dist.common-files) ' ' | grep "[ /]$$f " >/dev/null \
            || { echo $$f: distcom fail >&2; exit 1; }; \
        done
 END
diff --git a/t/colon5.sh b/t/colon5.sh
index aac3c22..4fe7b51 100755
--- a/t/colon5.sh
+++ b/t/colon5.sh
@@ -39,7 +39,7 @@ test-grep:
        grep '=GrEp$(empty)Me_am=' Makefile
        grep '=GrEp$(empty)Me_dep=' Makefile
 test-distcommon:
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]Makefile.dep '
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]Makefile.dep '
 test-distdir: distdir
        test -f $(distdir)/Makefile.dep
 END
diff --git a/t/confh.sh b/t/confh.sh
index 6da0429..03b5a0b 100755
--- a/t/confh.sh
+++ b/t/confh.sh
@@ -27,8 +27,8 @@ END
 cat > Makefile.am << 'END'
 .PHONY: test1 test2
 test1:
-       @echo am__dist_common = $(am__dist_common)
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]include/config\.h\.in '
+       @echo am.dist.common-files = $(am.dist.common-files)
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]include/config\.h\.in '
 test2: distdir
        ls -l $(distdir)/*
        test -f $(distdir)/include/config.h.in
diff --git a/t/confh8.sh b/t/confh8.sh
index 009ae30..dd83c4e 100755
--- a/t/confh8.sh
+++ b/t/confh8.sh
@@ -27,11 +27,11 @@ END
 cat > Makefile.am << 'END'
 .PHONY: test0 test1 test2
 test0:
-       @echo am__dist_common = $(am__dist_common)
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]one\.h\.in '
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]two\.h\.in '
+       @echo am.dist.common-files = $(am.dist.common-files)
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]one\.h\.in '
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]two\.h\.in '
        # Processed header files should not be distributed.
-       if echo ' ' $(am__dist_common) ' ' | grep '\.h '; then \
+       if echo ' ' $(am.dist.common-files) ' ' | grep '\.h '; then \
          exit 1; \
        else \
          exit 0; \
diff --git a/t/depdist.sh b/t/depdist.sh
index 103308e..e8baf26 100755
--- a/t/depdist.sh
+++ b/t/depdist.sh
@@ -43,7 +43,7 @@ SUBDIRS = subdir
 check-local: test1 test2
 .PHONY: test1 test2
 test1:
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]config/depcomp '
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]config/depcomp '
 test2: distdir
        ls -l $(distdir)/*
        test -f $(distdir)/config/depcomp
diff --git a/t/dist-auxfile.sh b/t/dist-auxfile.sh
index baa8d27..763b14e 100755
--- a/t/dist-auxfile.sh
+++ b/t/dist-auxfile.sh
@@ -47,10 +47,10 @@ END
     SUBDIRS = subdir
     test: distdir
        ls -l $(distdir) $(distdir)/*              # For debugging.
-       @echo am__dist_common = $(am__dist_common) # Likewise.
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]$(auxdir)foo.txt '
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]$(auxdir)bar.sh '
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]$(auxdir)zardoz '
+       @echo am.dist.common-files = $(am.dist.common-files) # Likewise.
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]$(auxdir)foo.txt '
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]$(auxdir)bar.sh '
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]$(auxdir)zardoz '
        test -f $(distdir)/$(auxdir)foo.txt
        test -f $(distdir)/$(auxdir)bar.sh
        test -f $(distdir)/$(auxdir)zardoz
diff --git a/t/distcom-subdir.sh b/t/distcom-subdir.sh
index c6b6926..3774a75 100755
--- a/t/distcom-subdir.sh
+++ b/t/distcom-subdir.sh
@@ -41,7 +41,7 @@ mkdir subdir
 cat > subdir/Makefile.am << 'END'
 .PHONY: test-distcom
 test-distcom:
-       echo ' ' $(am__dist_common) ' ' | $(FGREP) ' $(top_srcdir)/depcomp '
+       echo ' ' $(am.dist.common-files) ' ' | $(FGREP) ' $(top_srcdir)/depcomp 
'
 END
 
 $ACLOCAL
@@ -53,7 +53,7 @@ cat >> subdir/Makefile.am << 'END'
 bin_PROGRAMS = foo
 .PHONY: test-distcom
 test-distcom:
-       echo ' ' $(am__dist_common) ' ' | $(FGREP) ' $(top_srcdir)/depcomp '
+       echo ' ' $(am.dist.common-files) ' ' | $(FGREP) ' $(top_srcdir)/depcomp 
'
 check-local: test-distcom
 END
 
diff --git a/t/distcom3.sh b/t/distcom3.sh
index d83409e..98446c1 100755
--- a/t/distcom3.sh
+++ b/t/distcom3.sh
@@ -36,7 +36,7 @@ $AUTOMAKE --add-missing --gnu >output 2>&1 || { cat output; 
exit 1; }
 cat output
 grep README output && exit 1
 
-sed -n -e '/^am__dist_common =.*\\$/ {
+sed -n -e '/^am.dist.common-files =.*\\$/ {
    :loop
    p
    n
@@ -46,7 +46,7 @@ sed -n -e '/^am__dist_common =.*\\$/ {
    t loop
    p
    n
-   }' -e '/^am__dist_common =/ p' Makefile.in | grep README
+   }' -e '/^am.dist.common-files =/ p' Makefile.in | grep README
 
 
 # Should warn about missing README.
diff --git a/t/distcom4.sh b/t/distcom4.sh
index 4d98b17..e588e23 100755
--- a/t/distcom4.sh
+++ b/t/distcom4.sh
@@ -45,7 +45,7 @@ mkdir tests
 cat > Makefile.am << 'END'
 .PHONY: test1 test 2
 test1:
-       for x in $(am__dist_files); do echo $$x; done \
+       for x in $(am.dist.all-files); do echo $$x; done \
          | grep 'tests/' > lst
        cat lst # For debugging.
        test `wc -l <lst` -eq 1
diff --git a/t/distcom5.sh b/t/distcom5.sh
index 4d3789d..5971f9e 100755
--- a/t/distcom5.sh
+++ b/t/distcom5.sh
@@ -49,13 +49,13 @@ SUBDIRS = tests
 test: distdir
        test -f $(distdir)/tests/wrapper.in
 check-local: test
-       for x in $(am__dist_files); do echo $$x; done \
+       for x in $(am.dist.all-files); do echo $$x; done \
          | grep tests && exit 1; :
 END
 
 cat > tests/Makefile.am <<'END'
 check-local:
-       for x in $(am__dist_files); do echo $$x; done \
+       for x in $(am.dist.all-files); do echo $$x; done \
          | grep wrapper.in > lst
        cat lst # For debugging.
        test `wc -l <lst` -eq 1
diff --git a/t/hdr-vars-defined-once.sh b/t/hdr-vars-defined-once.sh
index a160c11..5101755 100755
--- a/t/hdr-vars-defined-once.sh
+++ b/t/hdr-vars-defined-once.sh
@@ -34,7 +34,7 @@ $AUTOMAKE
 test $(grep -c '^srcdir' Makefile.in) -eq 1
 
 # Also make sure include file is distributed.
-sed -n -e '/^am__dist_common =.*\\$/ {
+sed -n -e '/^am.dist.common-files =.*\\$/ {
    :loop
    p
    n
@@ -44,6 +44,6 @@ sed -n -e '/^am__dist_common =.*\\$/ {
    t loop
    p
    n
-   }' -e '/^am__dist_common =/ p' Makefile.in | grep 
Will_Be_Included_In_Makefile
+   }' -e '/^am.dist.common-files =/ p' Makefile.in | grep 
Will_Be_Included_In_Makefile
 
 :
diff --git a/t/insh2.sh b/t/insh2.sh
index 9d1a3a1..cc964cf 100755
--- a/t/insh2.sh
+++ b/t/insh2.sh
@@ -25,7 +25,7 @@ pkgdata_DATA =
 .PHONY: test
 test: distdir
        find $(distdir) # For debugging.
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]install-sh '
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]install-sh '
        test -f $(distdir)/install-sh
 END
 
diff --git a/t/libobj7.sh b/t/libobj7.sh
index b5e6742..d3874c5 100755
--- a/t/libobj7.sh
+++ b/t/libobj7.sh
@@ -39,10 +39,10 @@ check-local: test1 test2 test3
 test1: all
        $(AR) tv libtu.a
 test2:
-       @echo am__dist_common = $(am__dist_common)
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]basename\.c '
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]dirname\.c '
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]am__dummy_function\.c '
+       @echo am.dist.common-files = $(am.dist.common-files)
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]basename\.c '
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]dirname\.c '
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]am__dummy_function\.c '
 test3: distdir
        test -f $(distdir)/basename.c
        test -f $(distdir)/dirname.c
diff --git a/t/nodist.sh b/t/nodist.sh
index 41083c3..cb79f61 100755
--- a/t/nodist.sh
+++ b/t/nodist.sh
@@ -34,7 +34,7 @@ $ACLOCAL
 $AUTOMAKE
 
 grep '^am_eyeball_OBJECTS' Makefile.in
-grep '^am__dist_sources =' Makefile.in
-grep '^am__dist_sources =.*nodist' Makefile.in && exit 1
+grep '^am.dist.sources =' Makefile.in
+grep '^am.dist.sources =.*nodist' Makefile.in && exit 1
 
 :
diff --git a/t/nodist3.sh b/t/nodist3.sh
index 33a2d5c..f80445a 100755
--- a/t/nodist3.sh
+++ b/t/nodist3.sh
@@ -32,6 +32,6 @@ $ACLOCAL
 $AUTOMAKE
 
 grep '^dist:' Makefile.in && exit 1
-grep 'am__dist_sources' Makefile.in && exit 1
+grep 'am.dist.sources' Makefile.in && exit 1
 
 :
diff --git a/t/pr2.sh b/t/pr2.sh
index 84973c9..70e17ee 100755
--- a/t/pr2.sh
+++ b/t/pr2.sh
@@ -22,7 +22,7 @@
 # like the following (among the Makefiles)
 #       README.foo:templ/README.foo.in
 # the generated dist target in the Makefile.in fails,
-# because am__dist_common will contain templ/README.foo.in
+# because am.dist.common-files will contain templ/README.foo.in
 # and the dist target will try to copy templ/README.foo.in
 # to the distribution directory before it creates a templ
 # subdirectory in the distribution directory.
diff --git a/t/substref.sh b/t/substref.sh
index d24bf13..827f45c 100755
--- a/t/substref.sh
+++ b/t/substref.sh
@@ -47,8 +47,8 @@ $MAKE test
 
 # This is unrelated to the rest of this test.  But while we are
 # at it, make sure we don't use am__helldl_SOURCES_DIST here, since
-# it's not needed.  am__dist_sources should contain $(helldl_SOURCES).
+# it's not needed.  am.dist.sources should contain $(helldl_SOURCES).
 grep am__helldl_SOURCES_DIST Makefile && exit 1
-grep 'am__dist_sources.*\$(helldl_SOURCES)' Makefile
+grep 'am.dist.sources.*\$(helldl_SOURCES)' Makefile
 
 :
diff --git a/t/test-driver-is-distributed.sh b/t/test-driver-is-distributed.sh
index 6e725c2..7675330 100755
--- a/t/test-driver-is-distributed.sh
+++ b/t/test-driver-is-distributed.sh
@@ -53,7 +53,7 @@ END
   unindent > tests/Makefile.am << END
     check-local: test-sub
     test-sub:
-       echo ' ' \$(am__dist_common) ' ' | grep '[ /]$test_driver '
+       echo ' ' \$(am.dist.common-files) ' ' | grep '[ /]$test_driver '
     TESTS = foo.test
     EXTRA_DIST = \$(TESTS)
 END
diff --git a/t/txinfo.sh b/t/txinfo.sh
index 3c73ecd..ff75bdd 100755
--- a/t/txinfo.sh
+++ b/t/txinfo.sh
@@ -28,8 +28,8 @@ cat > Makefile.am << 'END'
 info_TEXINFOS = textutils.texi
 .PHONY: test1 test2
 test1:
-       @echo am__dist_files = $(am__dist_files)
-       echo ' ' $(am__dist_files) ' ' | grep '[ /]texinfo\.tex '
+       @echo am.dist.all-files = $(am.dist.all-files)
+       echo ' ' $(am.dist.all-files) ' ' | grep '[ /]texinfo\.tex '
 test2: distdir
        ls -l $(distdir)
        test -f $(distdir)/texinfo.tex
diff --git a/t/txinfo2.sh b/t/txinfo2.sh
index 78a4271..d52231a 100755
--- a/t/txinfo2.sh
+++ b/t/txinfo2.sh
@@ -27,8 +27,8 @@ cat > Makefile.am << 'END'
 info_TEXINFOS = textutils.texi
 .PHONY: test
 test:
-       @echo am__dist_files = $(am__dist_files)
-       case '$(am__dist_files)' in *'~'*) exit 1;; *) exit 0;; esac
+       @echo am.dist.all-files = $(am.dist.all-files)
+       case '$(am.dist.all-files)' in *'~'*) exit 1;; *) exit 0;; esac
 END
 
 : > texinfo.tex
diff --git a/t/txinfo8.sh b/t/txinfo8.sh
index 72ae61b..45c3c09 100755
--- a/t/txinfo8.sh
+++ b/t/txinfo8.sh
@@ -32,8 +32,8 @@ cat > Makefile.am << 'END'
 info_TEXINFOS = textutils.texi
 .PHONY: test1 test2
 test1:
-       @echo am__dist_files = $(am__dist_files)
-       echo ' ' $(am__dist_files) ' ' | grep '[ /]auxdir/texinfo\.tex '
+       @echo am.dist.all-files = $(am.dist.all-files)
+       echo ' ' $(am.dist.all-files) ' ' | grep '[ /]auxdir/texinfo\.tex '
 test2: distdir
        ls -l $(distdir)/*
        test -f $(distdir)/auxdir/texinfo.tex
diff --git a/t/vtexi3.sh b/t/vtexi3.sh
index dd897e0..4480ec4 100755
--- a/t/vtexi3.sh
+++ b/t/vtexi3.sh
@@ -41,7 +41,7 @@ cat > Makefile.am << 'END'
 info_TEXINFOS = foobar.texi quux.texi zardoz.texi
 .PHONY: echo-distfiles
 echo-distfiles:
-       @echo ' ' $(am__dist_files) ' '
+       @echo ' ' $(am.dist.all-files) ' '
 END
 
 cat > foobar.texi << 'END'
@@ -94,7 +94,7 @@ do_check ()
   vmonth=$(grep 'address@hidden UPDATED ' $srcdir/$vfile.texi | awk '{print 
$4, $5}')
   grep "address@hidden UPDATED-MONTH $vmonth$" $srcdir/$vfile.texi
   # Check that the vers*.texi file is distributed according
-  # to $(am__dist_files).
+  # to $(am.dist.all-files).
   $MAKE echo-distfiles # For debugging.
   $MAKE -s echo-distfiles | grep "[ /]$vfile\\.texi"
 }
diff --git a/t/vtexi4.sh b/t/vtexi4.sh
index abd1411..ed784db 100755
--- a/t/vtexi4.sh
+++ b/t/vtexi4.sh
@@ -55,8 +55,8 @@ test-grepinfo:
        cat $(srcdir)/foo.info | grep 'GREPDATE=$(my_date_rx)='
        cat $(srcdir)/foo.info | grep 'GREPMONTH=$(my_month_rx)='
 test-distfiles:
-       @echo am__dist_files = $(am__dist_files)
-       echo ' ' $(am__dist_files) ' ' | grep '[ /]version.texi '
+       @echo am.dist.all-files = $(am.dist.all-files)
+       echo ' ' $(am.dist.all-files) ' ' | grep '[ /]version.texi '
 test-distdir: distdir
        ls -l $(distdir)
        diff $(srcdir)/version.texi $(distdir)/version.texi
diff --git a/t/yacc-basic.sh b/t/yacc-basic.sh
index 2a98f9f..e8b2602 100755
--- a/t/yacc-basic.sh
+++ b/t/yacc-basic.sh
@@ -34,7 +34,7 @@ bar_YFLAGS = -v
 
 .PHONY: echo-distcom
 echo-distcom:
-       @echo ' ' $(am__dist_common) ' '
+       @echo ' ' $(am.dist.common-files) ' '
 END
 
 cat > parse.y << 'END'
diff --git a/t/yacc-cxx.sh b/t/yacc-cxx.sh
index 2d284f4..ce27e6a 100755
--- a/t/yacc-cxx.sh
+++ b/t/yacc-cxx.sh
@@ -38,7 +38,7 @@ foo4_YFLAGS = $(foo3_YFLAGS)
 
 .PHONY: echo-distcom
 echo-distcom:
-       @echo ' ' $(am__dist_common) ' '
+       @echo ' ' $(am.dist.common-files) ' '
 END
 
 cat > parse1.yy << 'END'
diff --git a/t/yacc-d-basic.sh b/t/yacc-d-basic.sh
index f8ff475..55f0ee5 100755
--- a/t/yacc-d-basic.sh
+++ b/t/yacc-d-basic.sh
@@ -39,7 +39,7 @@ bin_PROGRAMS = zardoz
 zardoz_SOURCES = parse.y main.c
 .PHONY: echo-distcom
 echo-distcom:
-       @echo ' ' $(am__dist_common) ' '
+       @echo ' ' $(am.dist.common-files) ' '
 END
 cp foo/Makefile.am bar/Makefile.am
 cp foo/Makefile.am baz/Makefile.am
diff --git a/t/yacc-d-cxx.sh b/t/yacc-d-cxx.sh
index 0483d8c..3e9e0d4 100755
--- a/t/yacc-d-cxx.sh
+++ b/t/yacc-d-cxx.sh
@@ -66,7 +66,7 @@ mkdir foo bar baz qux baz/sub
 cat > Makefile.am <<'END'
 .PHONY: echo-distcom
 echo-distcom:
-       @echo ' ' $(am__dist_common) ' '
+       @echo ' ' $(am.dist.common-files) ' '
 END
 cp Makefile.am foo/Makefile.am
 cp Makefile.am bar/Makefile.am
diff --git a/t/yacc-lex-cxx-alone.sh b/t/yacc-lex-cxx-alone.sh
index e669cbc..46e81ad 100755
--- a/t/yacc-lex-cxx-alone.sh
+++ b/t/yacc-lex-cxx-alone.sh
@@ -34,8 +34,8 @@ bar_SOURCES = bar.lxx
 
 .PHONY: check-dist
 check-dist: distdir
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]foo\.cc'
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]bar\.cxx'
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]foo\.cc'
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]bar\.cxx'
        ls -l $(distdir)
        test -f $(distdir)/foo.cc
        test -f $(distdir)/bar.cxx
diff --git a/t/colon7.sh b/t/colon7.sh
index 4254c5b..8dc623f 100755
--- a/t/colon7.sh
+++ b/t/colon7.sh
@@ -33,10 +33,10 @@ mkdir subdir
 : > Makefile.am
 : > subdir/foo
 cat > subdir/Makefile.am << 'END'
 # am__dist_common should contain 'foo', not 'subdir/foo'.
 test:
-       case '$(am__dist_common)' in *subdir/foo*) exit 1;; *) exit 0;; esac
-       echo ' ' $(am__dist_common) ' ' | grep '[ /]foo '
+       case '$(am.dist.common-files)' in *subdir/foo*) exit 1;; *) exit 0;; 
esac
+       echo ' ' $(am.dist.common-files) ' ' | grep '[ /]foo '
 .PHONY: test
 END
 
@@ -33,10 +33,10 @@ mkdir subdir
 : > subdir/foo
 cat > subdir/Makefile.am << 'END'
-# am__dist_common should contain 'foo', not 'subdir/foo'.
+# am.dist.common-files should contain 'foo', not 'subdir/foo'.
 test:
diff --git a/t/distcom2.sh b/t/distcom2.sh
index 28cc53b..b96eefd 100755
--- a/t/distcom2.sh
+++ b/t/distcom2.sh
@@ -14,7 +14,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # Test to make sure that depcomp and compile are added to am__dist_common.
 # Report from Pavel Roskin.  Report of problems with '--no-force' from
 # Scott James Remnant (Debian #206299)
 
@@ -50,7 +50,7 @@ for opt in '' --no-force; do
   test -f depcomp
 
   for dir in . subdir; do
-    sed -n 's/^am__dist_common = *\(.*\)$/ \1 /p' \
+    sed -n 's/^am.dist.common-files = *\(.*\)$/ \1 /p' \
       <$dir/Makefile.in >$dir/dc.txt
   done
 
@@ -58,7 +58,7 @@ for opt in '' --no-force; do
   cat subdir/dc.txt # Likewise.
 
   $FGREP ' $(am__config_aux_dir)/depcomp ' subdir/dc.txt
   # The 'compile' script will be listed in the am__dist_common of
   # the top-level Makefile because it's required in configure.ac
   # (by AM_PROG_CC_C_O).
   $FGREP ' $(am__config_aux_dir)/compile ' dc.txt \
@@ -14,7 +14,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-# Test to make sure that depcomp and compile are added to am__dist_common.
+# Test to make sure that depcomp and compile are added to am.dist.common-files.
 # Report from Pavel Roskin.  Report of problems with '--no-force' from
 # Scott James Remnant (Debian #206299)
@@ -58,7 +58,7 @@ for opt in '' --no-force; do
 
   $FGREP ' $(am__config_aux_dir)/depcomp ' subdir/dc.txt
-  # The 'compile' script will be listed in the am__dist_common of
+  # The 'compile' script will be listed in the am.dist.common-files of
   # the top-level Makefile because it's required in configure.ac
   # (by AM_PROG_CC_C_O).
-- 
1.7.10.4




reply via email to

[Prev in Thread] Current Thread [Next in Thread]